# pyflies-psychopy changelog

All _notable_ changes to this project will be documented in this file.

The format is based on _[Keep a Changelog][keepachangelog]_, and this project
adheres to _[Semantic Versioning][semver]_.

Everything that is documented in the [official docs][textXDocs] is considered
the part of the public API.

Backward incompatible changes are marked with **(BIC)**. These changes are the
reason for the major version increase so when upgrading between major versions
please take a look at related PRs and issues and see if the change affects you.

## [Unreleased]

[Unreleased]: https://github.com/pyflies/pyflies-psychopy/compare/0.2.0...HEAD


## [0.2.0] (released: 2021-01-12)

- Use of `sound.Sound` class for audio. Back-end is configured in user
  preferences.
- Added target config parameters in README.
- Various fixes.

[0.2.0]: https://github.com/pyflies/pyflies-psychopy/compare/0.1.1...0.2.0


## [0.1.1] (released: 2020-11-02)

- Fix CSV generator file delimiter

[0.1.1]: https://github.com/pyflies/pyflies-psychopy/compare/0.1.0...0.1.1


## [0.1.0] (released: 2020-11-01)

- Initial release


[0.1.0]: https://github.com/pyflies/pyflies-psychopy/compare/360ff9bea62834c63...0.1.0


[keepachangelog]: https://keepachangelog.com/
[semver]: https://semver.org/spec/v2.0.0.html
[textXDocs]: http://textx.github.io/textX/latest/
